compatibility_hash

Function compatibility_hash 

#[unsafe(no_mangle)]
pub extern "C" fn compatibility_hash() -> u64
This function is exposed so that the version linked into a plugin provider may be compared to the one linked into the plugin host.