PluginRegistrar

Struct PluginRegistrar 

pub struct PluginRegistrar<T>
where T: Plugin,
{ /* private fields */ }
A registrar is created by a plugin manager and provided to the library’s registration function to register any plugins it has.

Implementations

Source

impl<T> PluginRegistrar<T>
where T: Plugin,

pub fn register(&mut self, plugin: T)

Register a plugin, this will store the plugin in the registrar until the registration is completed. After the registration function completes, the plugin manager will add all plugins, if no errors were reported.

pub fn error(&mut self, error: Box<dyn Error>)

Inform the registrar of an error, note that if multiple are recorded only the last will propagate out of the plugin manager.