pub struct PluginRegistrar<T>where
T: Plugin,{ /* private fields */ }Expand description
A registrar is created by a plugin manager and provided to the library’s registration function to register any plugins it has.
Implementations
Sourceimpl<T> PluginRegistrar<T>where
T: Plugin,
impl<T> PluginRegistrar<T>where
T: Plugin,